@@ -14,8 +14,8 @@ from napari.types import LayerData
 
 from napari_deeplabcut import misc
 
-SUPPORTED_IMAGES = "jpg", "jpeg", "png"
-SUPPORTED_VIDEOS = "mp4", "mov", "avi"
+SUPPORTED_IMAGES = ".jpg", ".jpeg", ".png"
+SUPPORTED_VIDEOS = ".mp4", ".mov", ".avi"
 
 
 def get_hdf_reader(path):
@@ -89,7 +89,7 @@ def read_images(path):
     # Retrieve filepaths exactly as parsed by pims
     filepaths = []
     for filepath in glob.iglob(path):
-        _, *relpath = filepath.rsplit(os.sep, 3)
+        relpath = Path(filepath).parts[-3:]
         filepaths.append(os.path.join(*relpath))
     params = {
         "name": "images",
@@ -268,7 +268,7 @@ def read_video(filename: str, opencv: bool = True):
             return stream.read_frame()
 
         lazy_imread = delayed(_read_frame)
-    else:
+    else:  # pragma: no cover
         from pims import PyAVReaderIndexed
 
         try:
