@@ -7,12 +7,12 @@ from types import MethodType
 from typing import Optional, Sequence, Union
 
 import numpy as np
+from napari._qt.widgets.qt_welcome import QtWelcomeLabel
 from napari.layers import Image, Points, Shapes, Tracks
 from napari.layers.points._points_key_bindings import register_points_action
 from napari.layers.utils import color_manager
 from napari.utils.events import Event
 from napari.utils.history import get_save_history, update_save_history
-from napari._qt.widgets.qt_welcome import QtWelcomeLabel
 from qtpy.QtCore import Qt, QTimer, Signal
 from qtpy.QtGui import QPainter
 from qtpy.QtWidgets import (
@@ -26,6 +26,8 @@ from qtpy.QtWidgets import (
     QMessageBox,
     QPushButton,
     QRadioButton,
+    QScrollArea,
+    QSizePolicy,
     QStyle,
     QStyleOption,
     QVBoxLayout,
@@ -138,7 +140,7 @@ class KeypointControls(QWidget):
         )
 
         status_bar = self.viewer.window._qt_window.statusBar()
-        self.last_saved_label = QLabel('')
+        self.last_saved_label = QLabel("")
         self.last_saved_label.hide()
         status_bar.insertPermanentWidget(0, self.last_saved_label)
 
@@ -181,12 +183,22 @@ class KeypointControls(QWidget):
         self._trail_cb.setEnabled(False)
         self._trail_cb.stateChanged.connect(self._show_trails)
         self._trails = None
+
+        self._view_scheme_cb = QCheckBox("Show color scheme", parent=self)
+
         vlayout.addWidget(trail_label)
         vlayout.addWidget(self._trail_cb)
+        vlayout.addWidget(self._view_scheme_cb)
+
         self._layout.addLayout(vlayout)
 
         self._radio_group = self._form_mode_radio_buttons()
 
+        self._color_scheme_display = self._form_color_scheme_display(self.viewer)
+
+        self._view_scheme_cb.toggled.connect(self._show_color_scheme)
+        self._view_scheme_cb.toggle()
+
         # Substitute default menu action with custom one
         for action in self.viewer.window.file_menu.actions():
             if "save selected layer" in action.text().lower():
@@ -204,6 +216,10 @@ class KeypointControls(QWidget):
             self.viewer.layers.move_selected(ind, 0)
             self.viewer.layers.select_next()  # Auto-select the Points layer
 
+    def _show_color_scheme(self):
+        show = self._view_scheme_cb.isChecked()
+        self._color_scheme_display.setVisible(show)
+
     def _show_trails(self, state):
         if state == Qt.Checked:
             if self._trails is None:
@@ -254,7 +270,6 @@ class KeypointControls(QWidget):
     def _store_crop_coordinates(self, *args):
         if not (project_path := self._images_meta.get("project")):
             return
-
         for layer in self.viewer.layers:
             if isinstance(layer, Shapes):
                 try:
@@ -302,6 +317,36 @@ class KeypointControls(QWidget):
         group.buttonClicked.connect(_func)
         return group
 
+    def _form_color_scheme_display(self, viewer):
+        display = ColorSchemeDisplay(parent=self)
+        self._update_color_scheme(display)
+
+        self.viewer.layers.events.inserted.connect(
+            partial(self._update_color_scheme, display)
+        )
+
+        return viewer.window.add_dock_widget(
+            display, name="Color scheme reference", area="left"
+        )
+
+    def _update_color_scheme(self, display):
+        for layer in self.viewer.layers:
+            if isinstance(layer, Points) and layer.metadata:
+
+                def to_hex(nparray):
+                    a = np.array(nparray * 255, dtype=int)
+                    rgb2hex = lambda r, g, b, _: f"#{r:02x}{g:02x}{b:02x}"
+                    res = rgb2hex(*a)
+                    return res
+
+                [
+                    display.add_entry(name, to_hex(color))
+                    for name, color in layer.metadata["face_color_cycles"][
+                        "label"
+                    ].items()
+                ]
+                break
+
     def _remap_frame_indices(self, layer):
         if not self._images_meta.get("paths"):
             return
@@ -394,6 +439,8 @@ class KeypointControls(QWidget):
     def on_remove(self, event):
         layer = event.value
         if isinstance(layer, Points):
+            if self._color_scheme_display is not None:
+                self.viewer.window.remove_dock_widget(self._color_scheme_display)
             self._stores.pop(layer, None)
             while self._menus:
                 menu = self._menus.pop()
@@ -508,8 +555,8 @@ class KeypointsDropdownMenu(QWidget):
         menu = self.menus["label"]
         menu.blockSignals(True)
         menu.clear()
-        menu.addItems(self.id2label[text])
         menu.blockSignals(False)
+        menu.addItems(self.id2label[text])
 
 
 def create_dropdown_menu(store, items, attr):
@@ -632,3 +679,100 @@ class QtWelcomeWidget(QWidget):
         """
         self._update_property("drag", False)
         self.sig_dropped.emit(event)
+
+
+class LabelPair(QWidget):
+    def __init__(self, color: str, name: str, parent: QWidget):
+        super().__init__(parent)
+
+        self._color = color
+        self._part_name = name
+
+        self.color_label = QLabel("", parent=self)
+        self.part_label = QLabel(name, parent=self)
+
+        self.color_label.setToolTip(name)
+        self.part_label.setToolTip(name)
+
+        self._format_label(self.color_label, 10, 10)
+        self._format_label(self.part_label)
+
+        self.color_label.setStyleSheet(f"background-color: {color};")
+
+        self._build()
+
+    @staticmethod
+    def _format_label(label: QLabel, height: int = None, width: int = None):
+        label.setSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed)
+        if height is not None:
+            label.setMaximumHeight(height)
+        if width is not None:
+            label.setMaximumWidth(width)
+
+    def _build(self):
+        layout = QHBoxLayout()
+        layout.addWidget(self.color_label, alignment=Qt.AlignmentFlag.AlignLeft)
+        layout.addWidget(self.part_label, alignment=Qt.AlignmentFlag.AlignLeft)
+        self.setLayout(layout)
+
+    @property
+    def color(self):
+        return self._color
+
+    @color.setter
+    def color(self, color: str):
+        self._color = color
+        self.color_label.setStyleSheet(f"background-color: {color};")
+
+    @property
+    def part_name(self):
+        return self._part_name
+
+    @part_name.setter
+    def part_name(self, part_name: str):
+        self._part_name = part_name
+        self.part_label.setText(part_name)
+        self.part_label.setToolTip(part_name)
+        self.color_label.setToolTip(part_name)
+
+
+class ColorSchemeDisplay(QScrollArea):
+    def __init__(self, parent):
+        super().__init__(parent)
+
+        self.scheme_dict = {}  # {name: color} mapping
+        self._layout = QVBoxLayout()
+        self._layout.setSpacing(0)
+        self._container = QWidget(
+            parent=self
+        )  # workaround to use setWidget, let me know if there's a better option
+
+        self._build()
+
+    def _build(self):
+        self._container.setSizePolicy(
+            QSizePolicy.Fixed, QSizePolicy.Maximum
+        )  # feel free to change those
+        self._container.setLayout(self._layout)
+        self._container.adjustSize()
+
+        self.setWidget(self._container)
+
+        self.setWidgetResizable(True)
+        self.setSizePolicy(
+            QSizePolicy.MinimumExpanding, QSizePolicy.MinimumExpanding
+        )  # feel free to change those
+        # self.setMaximumHeight(150)
+        self.setBaseSize(100, 200)
+
+        self.setVerticalScrollBarPolicy(Qt.ScrollBarPolicy.ScrollBarAlwaysOn)
+        self.setHorizontalScrollBarPolicy(Qt.ScrollBarPolicy.ScrollBarAlwaysOff)
+
+    def add_entry(self, name, color):
+        self.scheme_dict.update({name: color})
+
+        self._layout.addWidget(
+            LabelPair(color, name, self), alignment=Qt.AlignmentFlag.AlignLeft
+        )
+        self._container.setLayout(self._layout)
+        self._container.update()
